@@ -10,19 +10,10 @@ namespace stan {
       return false;
     }
 
-    bool is_no_op_statement_vis::operator()(const assignment& st) const {
-      return false;
-    }
-
     bool is_no_op_statement_vis::operator()(const assgn& st) const {
       return false;
     }
 
-    bool is_no_op_statement_vis::operator()(const compound_assignment& st)
-      const {
-      return false;
-    }
-
     bool is_no_op_statement_vis::operator()(const sample& st) const {
       return false;
     }
@@ -44,6 +35,16 @@ namespace stan {
       return false;
     }
 
+    bool is_no_op_statement_vis
+      ::operator()(const for_array_statement& st) const {
+      return false;
+    }
+
+    bool is_no_op_statement_vis
+      ::operator()(const for_matrix_statement& st) const {
+      return false;
+    }
+
     bool is_no_op_statement_vis::operator()(
                                     const conditional_statement& st) const {
       return false;
