@@ -2,6 +2,7 @@
 #define STAN_LANG_AST_NODE_ASSGN_DEF_HPP
 
 #include <stan/lang/ast.hpp>
+#include <string>
 #include <vector>
 
 namespace stan {
@@ -10,8 +11,12 @@ namespace stan {
     assgn::assgn() { }
 
     assgn::assgn(const variable& lhs_var, const std::vector<idx>& idxs,
-                 const expression& rhs)
-      : lhs_var_(lhs_var), idxs_(idxs), rhs_(rhs) { }
+                 const std::string& op, const expression& rhs)
+      : lhs_var_(lhs_var), idxs_(idxs), op_(op), rhs_(rhs) { }
+
+    bool assgn::is_simple_assignment() const {
+      return !op_.compare("=");
+    }
 
     bool assgn::lhs_var_occurs_on_rhs() const {
       var_occurs_vis vis(lhs_var_);
