@@ -6,16 +6,16 @@
 namespace stan {
   namespace lang {
 
-    conditional_op::conditional_op() { }
+    conditional_op::conditional_op()
+      : has_var_(false) { }
 
     conditional_op::conditional_op(const expression& cond,
                                    const expression& true_val,
                                    const expression& false_val)
-      : cond_(cond),
-        true_val_(true_val),
-        false_val_(false_val),
+      : cond_(cond), true_val_(true_val), false_val_(false_val),
         type_(promote_primitive(true_val.expression_type(),
-                                false_val.expression_type())) {
+                                false_val.expression_type())),
+        has_var_(false), scope_() {
     }
 
   }
