@@ -19,6 +19,7 @@ namespace stan {
     struct integrate_ode_control;
     struct algebra_solver;
     struct algebra_solver_control;
+    struct map_rect;
     struct index_op;
     struct index_op_sliced;
     struct conditional_op;
@@ -42,6 +43,7 @@ namespace stan {
       expr_type operator()(const integrate_ode_control& e) const;
       expr_type operator()(const algebra_solver& e) const;
       expr_type operator()(const algebra_solver_control& e) const;
+      expr_type operator()(const map_rect& e) const;
       expr_type operator()(const index_op& e) const;
       expr_type operator()(const index_op_sliced& e) const;
       expr_type operator()(const conditional_op& e) const;
