@@ -2,6 +2,7 @@
 #define STAN_LANG_AST_SIGS_FUNCTION_SIGNATURE_T_HPP
 
 #include <stan/lang/ast/expr_type.hpp>
+#include <stan/lang/ast/sigs/function_arg_type.hpp>
 #include <utility>
 #include <vector>
 
@@ -12,7 +13,8 @@ namespace stan {
      * The type of a function signature, mapping a vector of
      * argument expression types to a result expression type.
      */
-    typedef std::pair<expr_type, std::vector<expr_type> > function_signature_t;
+    typedef std::pair<expr_type, std::vector<function_arg_type> >
+    function_signature_t;
 
   }
 }
