@@ -5,6 +5,7 @@
 #include <stan/lang/generator/constants.hpp>
 #include <stan/lang/generator/generate_arg_decl.hpp>
 #include <boost/lexical_cast.hpp>
+#include <cstddef>
 #include <ostream>
 #include <string>
 
@@ -65,7 +66,7 @@ namespace stan {
 
       o << "std::ostream* pstream__";
       if (parameter_defaults) {
-        o << " = 0";
+        o << " = nullptr";
       }
 
       o << ")";
