@@ -1,7 +1,7 @@
 #ifndef STAN_MCMC_HMC_XHMC_ADAPT_DIAG_E_XHMC_HPP
 #define STAN_MCMC_HMC_XHMC_ADAPT_DIAG_E_XHMC_HPP
 
-#include <stan/callbacks/writer.hpp>
+#include <stan/callbacks/logger.hpp>
 #include <stan/mcmc/stepsize_var_adapter.hpp>
 #include <stan/mcmc/hmc/xhmc/diag_e_xhmc.hpp>
 
@@ -23,22 +23,20 @@ namespace stan {
       ~adapt_diag_e_xhmc() {}
 
       sample
-      transition(sample& init_sample,
-                 callbacks::writer& info_writer,
-                 callbacks::writer& error_writer) {
+      transition(sample& init_sample, callbacks::logger& logger) {
         sample s = diag_e_xhmc<Model, BaseRNG>::transition(init_sample,
-                                                           info_writer,
-                                                           error_writer);
+                                                           logger);
 
         if (this->adapt_flag_) {
           this->stepsize_adaptation_.learn_stepsize(this->nom_epsilon_,
                                                     s.accept_stat());
 
-          bool update = this->var_adaptation_.learn_variance(this->z_.mInv,
-                                                             this->z_.q);
+          bool update = this->var_adaptation_.learn_variance(
+                                              this->z_.inv_e_metric_,
+                                              this->z_.q);
 
           if (update) {
-            this->init_stepsize(info_writer);
+            this->init_stepsize(logger);
 
             this->stepsize_adaptation_.set_mu(log(10 * this->nom_epsilon_));
             this->stepsize_adaptation_.restart();
