@@ -5,12 +5,14 @@
 
 #include <stan/io/cmd_line.hpp>
 #include <stan/io/dump.hpp>
+#include <stan/io/program_reader.hpp>
 #include <stan/io/reader.hpp>
 #include <stan/io/writer.hpp>
 
 #include <stan/lang/rethrow_located.hpp>
 #include <stan/model/prob_grad.hpp>
 #include <stan/model/indexing.hpp>
+#include <stan/services/util/create_rng.hpp>
 
 #include <boost/exception/all.hpp>
 #include <boost/random/additive_combine.hpp>
