@@ -7,11 +7,10 @@
 
 namespace stan {
 
-  template <typename T>
-  struct is_constant_struct<std::vector<T> > {
-    enum { value = is_constant_struct<T>::value };
-  };
+template <typename T>
+struct is_constant_struct<std::vector<T> > {
+  enum { value = is_constant_struct<T>::value };
+};
 
-}
+}  // namespace stan
 #endif
-
