@@ -5,12 +5,10 @@
 #include <ostream>
 
 namespace stan {
-  namespace math {
+namespace math {
 
-    inline void stan_print(std::ostream* o, const var& x) {
-      *o << x.val();
-    }
+inline void stan_print(std::ostream* o, const var& x) { *o << x.val(); }
 
-  }
-}
+}  // namespace math
+}  // namespace stan
 #endif
